.. _authplugin_module:

:mod:`cubicweb.pyramid.authplugin`
----------------------------------

.. automodule:: cubicweb.pyramid.authplugin

    .. autoclass:: DirectAuthentifier
        :show-inheritance:
        :members:
